@@ -19,7 +19,10 @@ import proto  # type: ignore
 
 
 __protobuf__ = proto.module(
-    package="google.monitoring.dashboard.v1", manifest={"Text",},
+    package="google.monitoring.dashboard.v1",
+    manifest={
+        "Text",
+    },
 )
 
 
@@ -41,7 +44,11 @@ class Text(proto.Message):
 
     content = proto.Field(proto.STRING, number=1)
 
-    format = proto.Field(proto.ENUM, number=2, enum=Format,)
+    format = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=Format,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
